/*
 * JSyntaxKeyword.java
 *
 * Created on 28 ottobre 2007, 21.47
 *
 */

package jsyntax;

import java.awt.Color;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import javax.swing.text.AttributeSet;
import javax.swing.text.SimpleAttributeSet;

/**
 *
 * @author Dario
 */
public class JSyntaxKeywordManager {
    
    private JSyntaxFormatter number_format;
    private JSyntaxFormatter normal_format;
    
    private Map<String,JSyntaxFormatter> key2format;
    private Set<JSyntaxFormatter> cache;
    
    /** Creates a new instance of JSyntaxKeyword */
    public JSyntaxKeywordManager() {
        this.key2format = new HashMap<String,JSyntaxFormatter>();
        this.cache = new HashSet<JSyntaxFormatter>();
        this.setNormalFormat(Color.BLACK,false,false,false);
        this.setNumberFormat(Color.MAGENTA,false,false,false);
    }
    
    public boolean isKeyword(JSyntaxToken token) {
        if (token.getToken() == null)
            return false;
        else return this.key2format.keySet().contains(token.getToken().toLowerCase());
    }
    
    public void setNumberFormat(Color color, boolean bold, boolean italic, boolean underline) {
        JSyntaxFormatter jsf = new JSyntaxFormatter(color,bold,italic,underline);
        if(this.cache.contains(jsf)) {
            // Find it
            for (Iterator<JSyntaxFormatter> it = this.cache.iterator() ; it.hasNext() ; ) {
                JSyntaxFormatter temp = it.next();
                if(temp.equals(jsf)) {
                    jsf = temp;
                    break;
                }
            }
        } else {
            this.cache.add(jsf);
        }
        
        this.number_format = jsf;
    }
    
    public void setNormalFormat(Color color, boolean bold, boolean italic, boolean underline) {
        JSyntaxFormatter jsf = new JSyntaxFormatter(color,bold,italic,underline);
        if(this.cache.contains(jsf)) {
            // Find it
            for (Iterator<JSyntaxFormatter> it = this.cache.iterator() ; it.hasNext() ; ) {
                JSyntaxFormatter temp = it.next();
                if(temp.equals(jsf)) {
                    jsf = temp;
                    break;
                }
            }
        } else {
            this.cache.add(jsf);
        }
        
        this.normal_format = jsf;
    }
    
    public JSyntaxFormatter getFormat(String key) {
        return this.key2format.get(key.toLowerCase());
    }
    
    public void addFormat(String key, Color color, boolean bold, boolean italic, boolean underline) {
        JSyntaxFormatter jsf = new JSyntaxFormatter(color,bold,italic,underline);
        if(this.cache.contains(jsf)) {
            // Find it
            for (Iterator<JSyntaxFormatter> it = this.cache.iterator() ; it.hasNext() ; ) {
                JSyntaxFormatter temp = it.next();
                if(temp.equals(jsf)) {
                    jsf = temp;
                    break;
                }
            }
        } else {
            this.cache.add(jsf);
        }
        
        this.key2format.put(key.toLowerCase(),jsf);
    }
    
    public void addFormat(Collection<String> keys, Color color, boolean bold, boolean italic, boolean underline) {
        JSyntaxFormatter jsf = new JSyntaxFormatter(color,bold,italic,underline);
        if(this.cache.contains(jsf)) {
            // Find it
            for (Iterator<JSyntaxFormatter> it = this.cache.iterator() ; it.hasNext() ; ) {
                JSyntaxFormatter temp = it.next();
                if(temp.equals(jsf)) {
                    jsf = temp;
                    break;
                }
            }
        } else {
            this.cache.add(jsf);
        }
        
        for(String ss : keys)
            this.key2format.put(ss.toLowerCase(),jsf);
    }

    public JSyntaxFormatter getNumberFormat() {
        return number_format;
    }
    
    public JSyntaxFormatter getNormalFormat() {
        return normal_format;
    }
    
}
