/*
 * JSyntaxManager.java
 *
 * Created on 28 ottobre 2007, 18.43
 *
 */

package jsyntax;

import java.awt.Color;
import java.awt.EventQueue;
import javax.swing.JTextPane;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.text.BadLocationException;
import javax.swing.text.DefaultStyledDocument;
import javax.swing.text.Document;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import jsyntax.JSyntaxKeywordManager;

/**
 * Class for binding JSyntaxDocument to JTextPane.
 * Example of use:
 * <code>
 * this.syntaxmanager = new JSyntaxManager(divisors, keywords);
 * this.syntaxmanager.registerJTextPane(this.jTextPane1);
 * </code>
 *
 * @author Dario Lucia
 * @version 1.0
 * @see jsyntax.JSyntaxKeywordManager
 * @see jsyntax.JSyntaxTokenDivisorManager
 * @see javax.swing.JTextPane
 */
public class JSyntaxManager {

    private JSyntaxKeywordManager keywords;
    private JSyntaxTokenDivisorManager divisors;
   
    /** Creates a new instance of JSyntaxManager */
    public JSyntaxManager(JSyntaxTokenDivisorManager divs, JSyntaxKeywordManager keys) {
        this.divisors = divs;
        this.keywords = keys;
    }

    public JSyntaxDocument getDocument(boolean undoSupport) {
        return new JSyntaxDocument(divisors,keywords,undoSupport);
    }
    
    public void registerJTextPane(JTextPane pane, boolean undoSupport) {
        JSyntaxDocument doc = this.getDocument(undoSupport);
        String text = pane.getText();
        doc.registerTextPane(pane);
        pane.setDocument(doc);
        pane.setText(text);
    }

    public JSyntaxTextPane getJSyntaxTextPane(boolean b) {
        return new JSyntaxTextPane(divisors,keywords,b);
    }
    
}
