/*
 * JSyntaxTokenizer.java
 *
 * Created on 28 ottobre 2007, 20.55
 *
 */

package jsyntax;

/**
 *
 * @author Dario
 */
public class JSyntaxTokenizer {
    
    private String toParse;
    private int currentIndex;
    private StringBuffer buffer;
    
    private String nextToken;
    private int nextIndex;
    
    private JSyntaxTokenDivisorManager divisors;
    private int stop;
           
    /** Creates a new instance of JSyntaxTokenizer */
    JSyntaxTokenizer(String toParse, int start, int end, JSyntaxTokenDivisorManager divs) {
        
        this.divisors = divs;
        initTokenizer(toParse,start,end);
    }
    
    JSyntaxTokenizer(JSyntaxTokenDivisorManager divs) {
        this.divisors = divs;
    }
    
    void initTokenizer(String toParse, int start, int end) {
        this.toParse = toParse;
        
        // Calc limits
        int i;
        for(i = start - 1;i>=0;i--) {
            char c = this.toParse.charAt(i);
            if(this.divisors.isTokenDivisor(c))
                break;
        }
        // Check
        if (i == -1) i=0;
        if(end >= this.toParse.length()) end = this.toParse.length() - 1;
        
        
        this.currentIndex = i;
        this.stop = end;
        
        this.buffer = new StringBuffer();
        
        this.nextToken = null;
        this.nextIndex = -1;
    }
    
    boolean hasNext() {
        // Reset the buffer
        buffer.delete(0,buffer.length());
        this.nextToken = null;
        this.nextIndex = -1;
        
        // Char read
        char read;
        if(this.currentIndex <= this.stop) {
            try {

                if(this.divisors.isTokenDivisor (read = this.toParse.charAt(this.currentIndex)) ) {
                    this.nextIndex = this.currentIndex;
                    this.currentIndex++;
                    buffer.append(read);
                    this.nextToken = this.buffer.toString();
                } else {
                    try {
                    // Char at this.currentIndex is valid: begin to read until next divisor token
                    this.nextIndex = this.currentIndex;

                    while(! this.divisors.isTokenDivisor (read = this.toParse.charAt(this.currentIndex))  ) {

                        buffer.append(read);
                        this.currentIndex++;
                    }
                    // Maybe I got it: let's store
                    this.nextToken = this.buffer.toString();
                    } catch(IndexOutOfBoundsException e) {
                        // End of the stream, but we got a token to return
                        this.nextToken = this.buffer.toString();
                    }
                }
            } catch(IndexOutOfBoundsException e) {
                // Nothing to do
            }
        }
        return this.nextToken != null;
    }
    
    JSyntaxToken getNext(JSyntaxToken token) {
        token.setIndex(this.nextIndex);
        token.setToken(this.nextToken);
        return token;
    }
    
}
