/*
 * JSyntaxUndoManager.java
 *
 * Created on 30 ottobre 2007, 19.47
 *
 */

package jsyntax.undo;

import java.util.LinkedList;
import java.util.Stack;
import jsyntax.JSyntaxDocument;

/**
 *
 * @author Dario Lucia
 */
public class JSyntaxUndoManager {
    
    private JSyntaxDocument document;
    
    private Stack<UndoableAction> undoStack;
    private Stack<UndoableAction> redoStack;
    
    /** Creates a new instance of JSyntaxUndoManager */
    public JSyntaxUndoManager(JSyntaxDocument doc) {
        this.document = doc;
        this.undoStack = new Stack<UndoableAction>();
        this.redoStack = new Stack<UndoableAction>();
    }
    
    public boolean canUndo() {
        return this.undoStack.size() != 0;
    }
    
    public boolean canRedo() {
        return this.redoStack.size() != 0;
    }
    
    public void undo() {
        if(this.undoStack.size() != 0) {
            UndoableAction action = this.undoStack.pop();
            action.undoOperation(this.document);
            this.redoStack.push(action);
        } else throw new IllegalStateException("No action in UndoableManager undo stack. Do you use canUndo?");
    }
    
    public void redo() {
        if(this.redoStack.size() != 0) {
            UndoableAction action = this.redoStack.pop();
            action.redoOperation(this.document);
            this.undoStack.push(action);
        } else throw new IllegalStateException("No action in UndoableManager redo stack. Do you use canRedo?");
    }
    
    public void addNewAction(UndoableAction action) {
        this.undoStack.push(action);
        this.redoStack.clear();
    }    
    
}
